$title

# Editing ${name_of(page.resource)}

Someone else has modified that page since you started your edits.

If you save right away, you risk to revert those changes (highlighted below as deletions).

Please review all those changes and manually merge them with your own changes.
If you're unsure about what you're doing, please press `Cancel` (losing your changes) and start editing the latest version of the page again.

Change information for future version ${page.version+1} (modified by $author):
${wiki_to_html(context(page.resource(version=None)), comment)}

## Review Changes Preview No changes

${wiki_to_html(context(page.resource), page.text)}
Sorry, this page has been modified by somebody else since you started editing. Your changes cannot be saved.